summaryrefslogtreecommitdiffstats
path: root/cmakemodules/FindKDEWIN32.cmake
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-11-16 13:38:23 -0600
committerTimothy Pearson <[email protected]>2011-11-16 13:38:23 -0600
commit07b42c91aa4a6363714fd194817d1be6466675bf (patch)
tree2880c0a8d5fea362270c6fbda0cb6a857a9d5dad /cmakemodules/FindKDEWIN32.cmake
parentfd9dca56be44910dfff4b1a174fdaa1a40ce1683 (diff)
downloadkbfx-07b42c91aa4a6363714fd194817d1be6466675bf.tar.gz
kbfx-07b42c91aa4a6363714fd194817d1be6466675bf.zip
Additional renaming of kde to tde
Diffstat (limited to 'cmakemodules/FindKDEWIN32.cmake')
-rw-r--r--cmakemodules/FindKDEWIN32.cmake10
1 files changed, 5 insertions, 5 deletions
diff --git a/cmakemodules/FindKDEWIN32.cmake b/cmakemodules/FindKDEWIN32.cmake
index afa8ee9..37470be 100644
--- a/cmakemodules/FindKDEWIN32.cmake
+++ b/cmakemodules/FindKDEWIN32.cmake
@@ -24,7 +24,7 @@ find_path(KDEWIN32_INCLUDE_DIR winposix_export.h
)
# at first find the kdewin32 library, this has to be compiled and installed before kdelibs/
# search for kdewin32 in the default install directory for applications (default of (n)make install)
set(KDEWIN32_LIBRARY_PATH ${_program_FILES_DIR}/kdewin32/lib)
@@ -42,7 +42,7 @@ if(MSVC)
if(MSVC_IDE)
# the ide needs the debug and release version
if( NOT KDEWIN32_LIBRARY_DEBUG OR NOT KDEWIN32_LIBRARY_RELEASE)
- message(FATAL_ERROR "\nCould NOT find the debug AND release version of the KDEWIN32 library.\nYou need to have both to use MSVC projects.\nPlease build and install both kdelibs/win/ libraries first.\n")
+ message(FATAL_ERROR "\nCould NOT find the debug AND release version of the KDEWIN32 library.\nYou need to have both to use MSVC projects.\nPlease build and install both tdelibs/win/ libraries first.\n")
endif( NOT KDEWIN32_LIBRARY_DEBUG OR NOT KDEWIN32_LIBRARY_RELEASE)
SET(KDEWIN32_LIBRARY optimized ${KDEWIN32_LIBRARY_RELEASE} debug ${KDEWIN32_LIBRARY_DEBUG})
else(MSVC_IDE)
@@ -57,8 +57,8 @@ else(MSVC)
set(KDEWIN32_LIBRARY ${KDEWIN32_LIBRARY_RELEASE})
endif(MSVC)
# kdelibs/win/ has to be built before the rest of kdelibs/
# eventually it will be moved out from kdelibs/
if (KDEWIN32_LIBRARY AND KDEWIN32_INCLUDE_DIR)
set(KDEWIN32_FOUND TRUE)
# add needed system libs
@@ -82,7 +82,7 @@ if (KDEWIN32_FOUND)
endif (NOT KDEWIN32_FIND_QUIETLY)
else (KDEWIN32_FOUND)
if (KDEWIN32_FIND_REQUIRED)
- message(FATAL_ERROR "Could NOT find KDEWIN32 library\nPlease build and install kdelibs/win/ first")
+ message(FATAL_ERROR "Could NOT find KDEWIN32 library\nPlease build and install tdelibs/win/ first")
endif (KDEWIN32_FIND_REQUIRED)
endif (KDEWIN32_FOUND)
@@ -24,7 +24,7 @@ find_path(KDEWIN32_INCLUDE_DIR winposix_export.h
)
-# at first find the kdewin32 library, this has to be compiled and installed before kdelibs/
+# at first find the kdewin32 library, this has to be compiled and installed before tdelibs/
# search for kdewin32 in the default install directory for applications (default of (n)make install)
set(KDEWIN32_LIBRARY_PATH ${_program_FILES_DIR}/kdewin32/lib)
@@ -57,8 +57,8 @@ else(MSVC)
set(KDEWIN32_LIBRARY ${KDEWIN32_LIBRARY_RELEASE})
endif(MSVC)
-# kdelibs/win/ has to be built before the rest of kdelibs/
-# eventually it will be moved out from kdelibs/
+# tdelibs/win/ has to be built before the rest of tdelibs/
+# eventually it will be moved out from tdelibs/
if (KDEWIN32_LIBRARY AND KDEWIN32_INCLUDE_DIR)
set(KDEWIN32_FOUND TRUE)